<?php
	/*
	 * date.php - version 0.0.4 2005/08/13
	 * 
	 * Description:
	 * Class for working with dates adapted for Serbian climate.
	 * Use date in timestamp14 format.
	 *
	 * Author: 
	 * Oliver Petkovic <oliver78@verat.net>
	 *
	 * Licence:
	 * Free
	 */

define('_DEBUG', false);
	 
class Date
{
	var $mYear; 
	var $mMonth;
	var $mDay;
	var $mHour;
	var $mMinute;
	var $mSecond;
		
	//
	//	Constructor
	//
	function Date($timeStamp, $timeZone)
	{
		if (($timeZone < -12) || ($timeZone > 12)) echo _DEBUG ? "<p><b>Error:</b> Wrong parameter \$timeZone</p>" : "";
		else
		if (strlen($timeStamp)!= 14) echo _DEBUG ? "<p><b>Error:</b> Parameter \$timeStamp is not 14 chars length</p>" : "";
		else
		{
			// year
			$set_year = substr($timeStamp, 0, 4);
					
			//month
			$set_month = substr($timeStamp, 4, 2);
					
			// day
			$set_day = substr($timeStamp, 6, 2);
					
			// hour
			$set_hour = substr($timeStamp, 8, 2);
					
			// minute
			$set_minute = substr($timeStamp, 10, 2);
				
			// second
			$set_second = substr($timeStamp, 12, 2);
		
			if (!@date("HisdmY", mktime($set_hour, $set_minute, $set_second, $set_month, $set_day, $set_year)) || ($set_hour=="") || ($set_minute =="") || ($set_second=="") || ($set_month=="") || ($set_day=="") || ($set_year==""))
			echo _DEBUG ? "<p><b>Error:</b> Wrong parameter \$timeStamp</p>" : "";
			else if (($timeZone < -12) || ($timeZone > 12)) echo _DEBUG ? "<p><b>Error:</b> Wrong parameter \$timeZone</p>" : "";
			else
			{
				$set_hour = $set_hour + $timeZone;
				$this->mYear = date("Y", mktime($set_hour, $set_minute, $set_second, $set_month, $set_day, $set_year));
				$this->mMonth = date("m", mktime($set_hour, $set_minute, $set_second, $set_month, $set_day, $set_year));
				$this->mDay = date("d", mktime($set_hour, $set_minute, $set_second, $set_month, $set_day, $set_year));
				$this->mHour = date("H", mktime($set_hour, $set_minute, $set_second, $set_month, $set_day, $set_year));
				$this->mMinute = date("i", mktime($set_hour, $set_minute, $set_second, $set_month, $set_day, $set_year));
				$this->mSecond = date("s", mktime($set_hour, $set_minute, $set_second, $set_month, $set_day, $set_year));
			}
		}
	}
	
	// Get functions
	function GetYear()
	{
		if (isset($this->mYear))
			return $this->mYear;
		else
			return _DEBUG ? "<b>Warning:</b> Parameter <b>mYear</b> is not set" : "";
	}
	function GetMonth()
	{
		if (isset($this->mMonth))
			return $this->mMonth;
		else
			return _DEBUG ? "<b>Warning:</b> Parameter <b>mMonth</b> is not set" : "";
			
	}
	function GetDay()
	{
		if (isset($this->mDay))
			return $this->mDay;
		else
			return _DEBUG ? "<b>Warning:</b> Parameter <b>mDay</b> is not set" : "";
	}
	function GetHour()
	{
		if (isset($this->mHour))
			return $this->mHour;
		else
			return _DEBUG ? "<b>Warning:</b> Parameter <b>mHour</b> is not set" : "";
	}
	function GetMinute()
	{
		if (isset($this->mMinute))
			return $this->mMinute;
		else
			return _DEBUG ? "<b>Warning:</b> Parameter <b>mMinute</b> is not set" : "";
	}
	function GetSecond()
	{
		if (isset($this->mSecond))
			return $this->mSecond;
		else
			return _DEBUG ? "<b>Warning:</b> Parameter <b>mSecond</b> is not set" : "";
	}
	
	//
	//	Function GetTime() returns time in (hh:mm) format.
	//
	function GetTime()
	{
		if ((!$time = @date("H:i", mktime($this->mHour, $this->mMinute, $this->mSecond, $this->mMonth, $this->mDay, $this->mYear))) || ($this->mHour=="") || ($this->mMinute=="")) return _DEBUG ? "<b>Warning:</b> Date is not well formed." : "";
		else 
		{
			$time = date("H:i", mktime($this->mHour, $this->mMinute, $this->mSecond, $this->mMonth, $this->mDay, $this->mYear));
			return $time;
		}
	}
	
	//
	//	Function GetFullTime() returns time in (hh:mm:ss) format.
	//
	function GetFullTime()
	{
		if ((!$time = @date("H:i:s", mktime($this->mHour, $this->mMinute, $this->mSecond, $this->mMonth, $this->mDay, $this->mYear))) || ($this->mHour=="") || ($this->mMinute=="") || ($this->mSecond=="")) return _DEBUG ? "<b>Warning:</b> Date is not well formed." : "";
		else
		{
			$time = date("H:i:s", mktime($this->mHour, $this->mMinute, $this->mSecond, $this->mMonth, $this->mDay, $this->mYear));
			return $time;
		}
	}
  
	//
	// Function GetDate() returns date in (dd. month yyyy.) format. (month = name of the month)
	//
	function GetDate()
	{
		if (!@date("dmY", mktime($this->mHour, $this->mMinute, $this->mSecond, $this->mMonth, $this->mDay, $this->mYear)) || ($this->mYear=="") || ($this->mMonth=="") || ($this->mDay=="")) return _DEBUG ? "<b>Warning:</b> Date is not well formed.": "";
		else
		{
			$date = date("dmY", mktime($this->mHour, $this->mMinute, $this->mSecond, $this->mMonth, $this->mDay, $this->mYear));
			$day = substr($date, 0, 2);
			$month = substr($date, 2, 2);
			$year = substr($date, 4, 4);
			
			// coversion
			switch($month)
			{
				case "01": $month = "januar";	break;
				case "02": $month = "februar";	break;
				case "03": $month = "mart";		break;
				case "04": $month = "april";		break;
				case "05": $month = "maj";		break;
				case "06": $month = "jun";		break;
				case "07": $month = "juli";		break;
				case "08": $month = "avgust";	break;
				case "09": $month = "septembar";	break;
				case "10": $month = "oktobar";	break;
				case "11": $month = "novembar";	break;
				case "12": $month = "decembar";	break;
			}
			
			// conversion (releasing the leading zero)
			switch($day)
			{
				case "01": $day=1;	break;
				case "02": $day=2;	break;
				case "03": $day=3;	break;
				case "04": $day=4;	break;
				case "05": $day=5;	break;
				case "06": $day=6;	break;		
				case "07": $day=7;	break;
				case "08": $day=8;	break;
				case "09": $day=9;	break;
			}
			
			$array = array($day,". ",$month, " ",$year,".");
			$date = implode("", $array);
			return $date;
		}
		
	}
	function GetDateStandard()
	{
		if (!@date("dmY", mktime($this->mHour, $this->mMinute, $this->mSecond, $this->mMonth, $this->mDay, $this->mYear)) || ($this->mYear=="") || ($this->mMonth=="") || ($this->mDay=="")) return _DEBUG ? "<b>Warning:</b> Date is not well formed.": "";
		else
		{
			$date = date("dmY", mktime($this->mHour, $this->mMinute, $this->mSecond, $this->mMonth, $this->mDay, $this->mYear));
			$day = substr($date, 0, 2);
			$month = substr($date, 2, 2);
			$year = substr($date, 4, 4);
			
			$array = array($day,". ",$month,". ",$year,".");
			$date = implode("", $array);
			return $date;
		}
		
	}
}
?>